@@ -2,7 +2,7 @@ package Leyland;
 
 # ABSTRACT: Plack-based framework for RESTful web applications
 
-our $VERSION = "0.001003";
+our $VERSION = "0.001004";
 $VERSION = eval $VERSION;
 
 use Moose;
@@ -24,7 +24,7 @@ Leyland - Plack-based framework for RESTful web applications
 
 =head1 VERSION
 
-version 0.001003
+version 0.001004
 
 =head1 SYNOPSIS
 
@@ -304,7 +304,7 @@ sub handle {
 				# we need to pass to the next matching route.
 				# first, let's erase the pass flag from the context
 				# so we don't try to do this infinitely
-				$c->_pass(0);
+				$c->_set_pass_next(0);
 				# no let's invoke the route
 				$ret = $c->_invoke_route;
 			}
@@ -487,6 +487,12 @@ sub _handle_exception {
 		return $c->_respond($exp->code);
 	}
 
+	# are we on the development environment? if so, and the exception
+	# has no mimes, we croak with a simple error message so that Plack
+	# displays a nice stack trace
+	croak $self->name.' croaked with HTTP status code '.$exp->code.' and error message "'.$err.'"'
+		if $self->cwe eq 'development' && !$exp->has_mimes;
+
 	# do we have templates for any of the client's requested MIME types?
 	# if so, render the first one you find.
 	if ($exp->has_mimes) {
